"use client";
import Image from "next/image";
import Link from "next/link";
import {RiMenu3Fill} from "react-icons/ri";
import {BsFacebook, BsInstagram, BsWhatsapp} from "react-icons/bs";

import {
  Sheet,
  SheetClose,
  SheetContent,
  SheetTrigger,
} from "@/components/ui/sheet";
import {cn} from "@/lib/utils";
import {usePathname} from "next/navigation";
import {Button} from "./ui/button";

interface Props {
  nav: any;
  socials: any;
  className?: string;
}

export default function SheetMB({nav, socials, className}: Props) {
  const pathname = usePathname();

  return (
    <Sheet>
      <SheetTrigger className="lg:hidden">
        <RiMenu3Fill size={30} className={cn(className)} />
      </SheetTrigger>
      <SheetContent className="space-y-5 flex flex-col justify-between">
        <div className="flex items-center justify-center">
          <Image
            src="/logo-black.svg"
            alt="Villa Batu"
            width={150}
            height={126}
            className="object-cover "
          />
        </div>
        <ul className="flex flex-col justify-center items-center gap-5 tracking-wide text-lg">
          {nav.map((item: any, index: number) => (
            <li key={index} className="text-[18px] tracking-wide font-semibold">
              <SheetClose asChild key={index}>
                <Link href={`/${item.link}`}>{item.title}</Link>
              </SheetClose>
            </li>
          ))}
        </ul>
        {pathname !== "/availability" && (
          <Button
            className="rounded-[3px] bg-main hover:bg-main/80 py-7"
            asChild
          >
            <Link
              href="/availability"
              className="font-semibold text-lg tracking-wide text-white font-Soraa"
            >
              Check Availability
            </Link>
          </Button>
        )}
        <div className="flex flex-col justify-center items-center gap-5 ">
          <div className="flex flex-row gap-5 justify-center items-center">
            <a href={socials.facebook} target="_blank" rel="noreferrer">
              <BsFacebook size={26} className="text-main" />
            </a>
            <a href={socials.instagram} target="_blank" rel="noreferrer">
              <BsInstagram size={26} className="text-main" />
            </a>
            <a href={socials.waLink} target="_blank" rel="noreferrer">
              <BsWhatsapp size={26} className="text-main" />
            </a>
          </div>
          <div className="text-black text-center tracking-wider">
            <a
              href="https://thetropicaldoor.com"
              target="_blank"
              className="text-sm"
              rel="noreferrer"
            >
              Managed by
              <br /> The Tropical Door
            </a>
          </div>
        </div>
      </SheetContent>
    </Sheet>
  );
}
